@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -32,17 +32,19 @@ class ThemeEditorMainWindow : public KXmlGuiWindow
     Q_OBJECT
 public:
     explicit ThemeEditorMainWindow();
-    ~ThemeEditorMainWindow();
+    ~ThemeEditorMainWindow() override;
 
 protected:
     void closeEvent(QCloseEvent *) override;
 
+private Q_SLOTS:
+    void slotUploadTheme();
+
 private:
     void slotNewTheme();
     void slotCloseTheme();
     void slotAddExtraPage();
     void slotOpenTheme();
-    void slotUploadTheme();
     void slotQuitApp();
     bool slotSaveTheme();
     void slotConfigure();
